@@ -1,9 +1,9 @@
 package Calendar::Indonesia::Holiday;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-12-08'; # DATE
+our $DATE = '2021-01-13'; # DATE
 our $DIST = 'Calendar-Indonesia-Holiday'; # DIST
-our $VERSION = '0.330'; # VERSION
+our $VERSION = '0.331'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1219,6 +1219,83 @@ sub list_id_workdays {
     Calendar::Indonesia::Holiday::enum_id_workdays(%fargs);
 }
 
+$SPEC{is_id_holiday} = {
+    v => 1.1,
+    summary => 'Check whether a date is an Indonesian holiday',
+    description => <<'_',
+
+Will return boolean if a given date is a holiday. A joint leave day will not
+count as holiday unless you specify `include_joint_leave` option.
+
+Date can be given using separate `day` (of month), `month`, and `year`, or as a
+single YYYY-MM-DD date.
+
+Will return undef (exit code 2 on CLI) if year is not within range of the
+holiday data.
+
+_
+    args => {
+        day        => {schema=>['int*', between=>[1,31]]},
+        month      => {schema=>['int*', between=>[1, 12]]},
+        year       => {schema=>'int*'},
+        date       => {schema=>'str*', pos=>0},
+
+        reverse    => {schema=>'bool*', cmdline_aliases=>{r=>{}}},
+        quiet      => {schema=>'bool*', cmdline_aliases=>{q=>{}}},
+        detail     => {schema=>'bool*', cmdline_aliases=>{l=>{}}},
+    },
+    args_rels => {
+        choose_all => [qw/day month year/],
+        req_one => [qw/day date/],
+    },
+};
+sub is_id_holiday {
+    my %args = @_;
+
+    my ($y, $m, $d);
+    if (defined $args{date}) {
+        $args{date} =~ /\A(\d{4})-(\d{1,2})-(\d{1,2})\z/
+            or return [400, "Invalid date syntax, please use 'YYYY-MM-DD' format"];
+        ($y, $m, $d) = ($1, $2, $3);
+    } else {
+        ($y = $args{year}) && ($m = $args{month}) && ($d = $args{day})
+            or return [400, "Please specify day/month/year or date"];
+    }
+    my $date = sprintf "%04d-%02d-%02d", $y, $m, $d;
+
+    for my $e (@fixed_holidays) {
+        next if defined $e->{year_start} && $y < $e->{year_start};
+        next if defined $e->{year_end} && $y > $e->{year_end};
+        next unless $e->{day} == $d && $e->{month} == $m;
+        return [200, "OK", ($args{reverse} ? 0 : ($args{detail} ? $e : 1)), {
+            'cmdline.exit_code' => ($args{reverse} ? 1 : 0),
+            ('cmdline.result' => ($args{quiet} ? '' : "Date $date IS a holiday")) x !$args{detail},
+        }];
+    }
+
+    unless ($y >= $min_year && $y <= $max_year) {
+        return [200, "OK", undef, {
+            'cmdline.exit_code' => 2,
+            'cmdline.result' => ($args{quiet} ? '' : "Date year ($y) is not within range of holiday data ($min_year-$max_year)"),
+        }];
+    }
+
+    for my $e (@{ $year_holidays{$y} }) {
+        next unless $e->{day} == $d && $e->{month} == $m;
+        next if $e->{is_joint_leave} && !$args{include_joint_leave};
+        return [200, "OK", ($args{reverse} ? 0 : ($args{detail} ? $e : 1)), {
+            'cmdline.exit_code' => ($args{reverse} ? 1 : 0),
+            ('cmdline.result' => ($args{quiet} ? '' : "Date $date IS a holiday")) x !$args{detail},
+        }];
+    }
+
+    return [200, "OK", ($args{reverse} ? 1:0), {
+        'cmdline.exit_code' => ($args{reverse} ? 0 : 1),
+        'cmdline.result' => ($args{quiet} ? '' : "Date $date is NOT a holiday"),
+    }];
+}
+
+
 1;
 # ABSTRACT: List Indonesian public holidays
 
@@ -1234,7 +1311,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.330 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2020-12-08.
+This document describes version 0.331 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-01-13.
 
 =head1 SYNOPSIS
 
@@ -1433,6 +1510,59 @@ Return value:  (any)
 
 
 
+=head2 is_id_holiday
+
+Usage:
+
+ is_id_holiday(%args) -> [status, msg, payload, meta]
+
+Check whether a date is an Indonesian holiday.
+
+Will return boolean if a given date is a holiday. A joint leave day will not
+count as holiday unless you specify C<include_joint_leave> option.
+
+Date can be given using separate C<day> (of month), C<month>, and C<year>, or as a
+single YYYY-MM-DD date.
+
+Will return undef (exit code 2 on CLI) if year is not within range of the
+holiday data.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<date> => I<str>
+
+=item * B<day> => I<int>
+
+=item * B<detail> => I<bool>
+
+=item * B<month> => I<int>
+
+=item * B<quiet> => I<bool>
+
+=item * B<reverse> => I<bool>
+
+=item * B<year> => I<int>
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 list_id_holidays
 
 Usage:
@@ -1938,7 +2068,7 @@ Source repository is at L<https://github.com/perlancar/perl-Calendar-Indonesia-H
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Calendar-Indonesia-Holiday>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Calendar-Indonesia-Holiday/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -1957,7 +2087,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
